home | help
OCT-RUN_REG...ION_TEST.PL(1)  octopus documentation OCT-RUN_REG...ION_TEST.PL(1)

SYNOPSIS
     oct-run_regression_test.pl [ option ]... [ file ]...

DESCRIPTION
     This script is one of the octopus utilities.

     This script can be used to generate and run the octopus regression tests.

     The man pages of Octopus and of the auxiliary Octopus sub-programs
     (oct-something) are not intended to contain the documentation of the pro-
     grams, but only their basic description. For where to find more documenta-
     tion, see the "SEE ALSO" section below.

     -n  Dry run. Don't run the test. Only print what would be executed.

     -v  Run in verbose mode. Useful for debugging the script.

     -h  Show a brief summary of command-line options.

     -D DIR
	 Directory where to look for the Octopus executables.

     -s SUFFIX
	 Suffix to append to the base executable name.

     -c file
	 Create a template for a Octopus regression test. This should always be
	 used if you create a new regression test.

     -f file
	 This option specifies the input file for a regression test.

     -i  Print content of the Octopus input file which is used for the current
	 test to stdout.

     -p  Preserve working directory. Don't clean up the temporary working direc-
	 tory after the run.

     -l  Copy outout log to current working directory.

     -m  Run matches only (assumes there are work directories present).

EXAMPLES
     To create a template for a regression test run, e.g.

	     oct-run_regression_test.pl -c finite_systems_3d/sodium.test

     Running a test can be achieved with

	     oct-run_regression_test.pl -f finite_systems_3d/sodium.test

     If a test run fails it might be useful for bug-tracing to preserve the
     working directory of this run and to print out the input file

	     oct-run_regression_test.pl -pi -f finite_systems_3d/sodium.test

     Run an MPI test with a local directory as working directory

	     oct-run_regression_test.pl -f benzene.test -D $PWD/../src -s _mpi

AUTHOR
     Written by H. Appel.

REPORTING BUGS
     Report bugs to <appel@physik.fu-berlin.de>.

COPYRIGHT
     Copyright (C) 2005 H. Appel.

     This is free software; see the source for copying conditions.  There is NO
     warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SEE ALSO
     The largest source of documentation is the Octopus wiki: http://octo-
     pus-code.org.

perl v5.42.3			   2025-10-21	    OCT-RUN_REG...ION_TEST.PL(1)

home | help